==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkTransformInterpolator.java <==
// java wrapper for vtkTransformInterpolator object
//

package vtk;
import vtk.*;

public class vtkTransformInterpolator extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfTransforms_2();
  public int GetNumberOfTransforms()
    { return GetNumberOfTransforms_2(); }

  private native double GetMinimumT_3();
  public double GetMinimumT()
    { return GetMinimumT_3(); }

  private native double GetMaximumT_4();
  public double GetMaximumT()
    { return GetMaximumT_4(); }

  private native void Initialize_5();
  public void Initialize()
    { Initialize_5(); }

  private native void AddTransform_6(double id0,vtkTransform id1);
  public void AddTransform(double id0,vtkTransform id1)
    { AddTransform_6(id0,id1); }

  private native void AddTransform_7(double id0,vtkMatrix4x4 id1);
  public void AddTransform(double id0,vtkMatrix4x4 id1)
    { AddTransform_7(id0,id1); }

  private native void AddTransform_8(double id0,vtkProp3D id1);
  public void AddTransform(double id0,vtkProp3D id1)
    { AddTransform_8(id0,id1); }

  private native void RemoveTransform_9(double id0);
  public void RemoveTransform(double id0)
    { RemoveTransform_9(id0); }

  private native void InterpolateTransform_10(double id0,vtkTransform id1);
  public void InterpolateTransform(double id0,vtkTransform id1)
    { InterpolateTransform_10(id0,id1); }

  private native void SetInterpolationType_11(int id0);
  public void SetInterpolationType(int id0)
    { SetInterpolationType_11(id0); }

  private native int GetInterpolationTypeMinValue_12();
  public int GetInterpolationTypeMinValue()
    { return GetInterpolationTypeMinValue_12(); }

  private native int GetInterpolationTypeMaxValue_13();
  public int GetInterpolationTypeMaxValue()
    { return GetInterpolationTypeMaxValue_13(); }

  private native int GetInterpolationType_14();
  public int GetInterpolationType()
    { return GetInterpolationType_14(); }

  private native void SetInterpolationTypeToLinear_15();
  public void SetInterpolationTypeToLinear()
    { SetInterpolationTypeToLinear_15(); }

  private native void SetInterpolationTypeToSpline_16();
  public void SetInterpolationTypeToSpline()
    { SetInterpolationTypeToSpline_16(); }

  private native void SetInterpolationTypeToManual_17();
  public void SetInterpolationTypeToManual()
    { SetInterpolationTypeToManual_17(); }

  private native void SetPositionInterpolator_18(vtkTupleInterpolator id0);
  public void SetPositionInterpolator(vtkTupleInterpolator id0)
    { SetPositionInterpolator_18(id0); }

  private native long GetPositionInterpolator_19();
  public vtkTupleInterpolator GetPositionInterpolator() {
    long temp = GetPositionInterpolator_19();

    if (temp == 0) return null;
    return (vtkTupleInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaleInterpolator_20(vtkTupleInterpolator id0);
  public void SetScaleInterpolator(vtkTupleInterpolator id0)
    { SetScaleInterpolator_20(id0); }

  private native long GetScaleInterpolator_21();
  public vtkTupleInterpolator GetScaleInterpolator() {
    long temp = GetScaleInterpolator_21();

    if (temp == 0) return null;
    return (vtkTupleInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRotationInterpolator_22(vtkQuaternionInterpolator id0);
  public void SetRotationInterpolator(vtkQuaternionInterpolator id0)
    { SetRotationInterpolator_22(id0); }

  private native long GetRotationInterpolator_23();
  public vtkQuaternionInterpolator GetRotationInterpolator() {
    long temp = GetRotationInterpolator_23();

    if (temp == 0) return null;
    return (vtkQuaternionInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_24();
  public int GetMTime()
    { return GetMTime_24(); }

  public vtkTransformInterpolator() { super(); }

  public vtkTransformInterpolator(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv7h.pkg.tar.xz: vtk/vtkTransformInterpolator.java <==
// java wrapper for vtkTransformInterpolator object
//

package vtk;
import vtk.*;

public class vtkTransformInterpolator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetNumberOfTransforms_2();
  public int GetNumberOfTransforms()
    { return GetNumberOfTransforms_2(); }

  private native double GetMinimumT_3();
  public double GetMinimumT()
    { return GetMinimumT_3(); }

  private native double GetMaximumT_4();
  public double GetMaximumT()
    { return GetMaximumT_4(); }

  private native void Initialize_5();
  public void Initialize()
    { Initialize_5(); }

  private native void AddTransform_6(double id0,vtkTransform id1);
  public void AddTransform(double id0,vtkTransform id1)
    { AddTransform_6(id0,id1); }

  private native void AddTransform_7(double id0,vtkMatrix4x4 id1);
  public void AddTransform(double id0,vtkMatrix4x4 id1)
    { AddTransform_7(id0,id1); }

  private native void AddTransform_8(double id0,vtkProp3D id1);
  public void AddTransform(double id0,vtkProp3D id1)
    { AddTransform_8(id0,id1); }

  private native void RemoveTransform_9(double id0);
  public void RemoveTransform(double id0)
    { RemoveTransform_9(id0); }

  private native void InterpolateTransform_10(double id0,vtkTransform id1);
  public void InterpolateTransform(double id0,vtkTransform id1)
    { InterpolateTransform_10(id0,id1); }

  private native void SetInterpolationType_11(int id0);
  public void SetInterpolationType(int id0)
    { SetInterpolationType_11(id0); }

  private native int GetInterpolationTypeMinValue_12();
  public int GetInterpolationTypeMinValue()
    { return GetInterpolationTypeMinValue_12(); }

  private native int GetInterpolationTypeMaxValue_13();
  public int GetInterpolationTypeMaxValue()
    { return GetInterpolationTypeMaxValue_13(); }

  private native int GetInterpolationType_14();
  public int GetInterpolationType()
    { return GetInterpolationType_14(); }

  private native void SetInterpolationTypeToLinear_15();
  public void SetInterpolationTypeToLinear()
    { SetInterpolationTypeToLinear_15(); }

  private native void SetInterpolationTypeToSpline_16();
  public void SetInterpolationTypeToSpline()
    { SetInterpolationTypeToSpline_16(); }

  private native void SetInterpolationTypeToManual_17();
  public void SetInterpolationTypeToManual()
    { SetInterpolationTypeToManual_17(); }

  private native void SetPositionInterpolator_18(vtkTupleInterpolator id0);
  public void SetPositionInterpolator(vtkTupleInterpolator id0)
    { SetPositionInterpolator_18(id0); }

  private native long GetPositionInterpolator_19();
  public vtkTupleInterpolator GetPositionInterpolator() {
    long temp = GetPositionInterpolator_19();

    if (temp == 0) return null;
    return (vtkTupleInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetScaleInterpolator_20(vtkTupleInterpolator id0);
  public void SetScaleInterpolator(vtkTupleInterpolator id0)
    { SetScaleInterpolator_20(id0); }

  private native long GetScaleInterpolator_21();
  public vtkTupleInterpolator GetScaleInterpolator() {
    long temp = GetScaleInterpolator_21();

    if (temp == 0) return null;
    return (vtkTupleInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetRotationInterpolator_22(vtkQuaternionInterpolator id0);
  public void SetRotationInterpolator(vtkQuaternionInterpolator id0)
    { SetRotationInterpolator_22(id0); }

  private native long GetRotationInterpolator_23();
  public vtkQuaternionInterpolator GetRotationInterpolator() {
    long temp = GetRotationInterpolator_23();

    if (temp == 0) return null;
    return (vtkQuaternionInterpolator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetMTime_24();
  public int GetMTime()
    { return GetMTime_24(); }

  public vtkTransformInterpolator() { super(); }

  public vtkTransformInterpolator(long id) { super(id); }
  public native long   VTKInit();

}
